Stan Math Library: stan/math/fwd/scal/fun/Phi.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Phi.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_PHI_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_PHI_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6 #include <stan/math/prim/scal/fun/Phi.hpp>
7 #include <stan/math/prim/scal/fun/constants.hpp>
8
9 namespace stan {
10
11 namespace math {
12
13 template <typename T>
14 inline fvar<T> Phi(const fvar<T>& x) {
15 using stan::math::Phi;
16 using std::exp;
17 using std::sqrt;
18 T xv = x.val_;
19 return fvar<T>(Phi(xv),
20 x.d_ * exp(xv * xv / -2.0) / sqrt(2.0 * stan::math::pi()));
21 }
22 }
23 }
24 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::sqrt
fvar< T > sqrt(const fvar< T > &x)
Definition: sqrt.hpp:15
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
stan::math::Phi
fvar< T > Phi(const fvar< T > &x)
Definition: Phi.hpp:14
constants.hpp
stan::math::pi
double pi()
Return the value of pi.
Definition: constants.hpp:86
Phi.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.